module.exports = defineTest({
	description: 'amd.define',
	options: {
		output: {
			amd: { define: 'enifed' }
		}
	}
});
